"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var crypto_browserify_1 = __importDefault(require("crypto-browserify"));
var I18n = /** @class */ (function () {
    function I18n(lang, texts) {
        this.lang = lang;
        this.dictionary = texts;
    }
    I18n.prototype.getLang = function () {
        return this.lang;
    };
    I18n.prototype.setLang = function (lang) {
        this.lang = lang;
    };
    I18n.prototype.translate = function (text) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        if (!text) {
            return '';
        }
        var translationString = text;
        var params = args;
        if (this.isTranslationObject(text)) {
            var obj = this.getTranslationObject(text);
            if (obj) {
                translationString = obj.raw;
                params = obj.params;
            }
        }
        var translation = this.getTranslation(translationString) || translationString;
        return this.format(translation, params);
    };
    I18n.prototype.isTranslationObject = function (text) {
        return I18n.TRANSLATION_OBJECT_REGEX.test(text);
    };
    I18n.prototype.getTranslationObject = function (text) {
        var stringifiedObject = text.replace(I18n.TRANSLATION_OBJECT_REGEX, '');
        var translationObject = null;
        try {
            translationObject = JSON.parse(stringifiedObject);
        }
        catch (err) {
            translationObject = null;
        }
        return translationObject;
    };
    I18n.prototype.getTranslation = function (text) {
        var textHash = this.createHash(text);
        var dictionaryItem = this.dictionary[textHash];
        if (!dictionaryItem) {
            return;
        }
        return dictionaryItem;
    };
    I18n.prototype.createHash = function (str) {
        return crypto_browserify_1.default
            .createHash('md5')
            .update(str.trim().toLowerCase())
            .digest('hex');
    };
    I18n.prototype.format = function (text, args) {
        if (args.length > 0) {
            for (var i = 0; i < args.length; i++) {
                text = text.replace(new RegExp("\\{" + i + "\\}", 'gi'), args[i]);
            }
            return text;
        }
        return text;
    };
    I18n.TRANSLATION_OBJECT_REGEX = /^\s*TRANSLATE:/g;
    return I18n;
}());
exports.default = I18n;
//# sourceMappingURL=I18n.js.map